@@ -31,6 +31,7 @@
 #include "openvswitch/poll-loop.h"
 #include "simap.h"
 #include "ovsdb-idl.h"
+#include "smap.h"
 #include "stream.h"
 #include "stream-ssl.h"
 #include "unixctl.h"
@@ -88,6 +89,20 @@ check_northd_version(struct ovsdb_idl *vtep_idl, struct ovsdb_idl *ovnsb_idl,
     return true;
 }
 
+/* Set probe interval, based on user configuration and the remote. */
+static void
+update_idl_probe_interval(struct ovsdb_idl *ovn_sb_idl,
+                          struct ovsdb_idl *vtep_idl)
+{
+    const struct vteprec_global *cfg = vteprec_global_first(vtep_idl);
+    int interval = -1;
+    if (cfg) {
+        interval = smap_get_int(&cfg->other_config,
+                                "ovn-remote-probe-interval", interval);
+    }
+    set_idl_probe_interval(ovn_sb_idl, ovnsb_remote, interval);
+}
+
 int
 main(int argc, char *argv[])
 {
@@ -101,7 +116,7 @@ main(int argc, char *argv[])
     parse_options(argc, argv);
     fatal_ignore_sigpipe();
 
-    daemonize_start(false);
+    daemonize_start(false, false);
 
     char *abs_unixctl_path = get_abs_unix_ctl_path(NULL);
     retval = unixctl_server_create(abs_unixctl_path, &unixctl);
@@ -160,6 +175,11 @@ main(int argc, char *argv[])
     char *ovn_version = ovn_get_internal_version();
     VLOG_INFO("OVN internal version is : [%s]", ovn_version);
 
+    unixctl_command_register("sb-connection-status", "", 0, 0,
+                             ovn_conn_show, ovnsb_idl_loop.idl);
+    unixctl_command_register("vtep-connection-status", "", 0, 0,
+                             ovn_conn_show, vtep_idl_loop.idl);
+
     /* Main loop. */
     exiting = false;
     while (!exiting) {
@@ -179,6 +199,8 @@ main(int argc, char *argv[])
             simap_destroy(&usage);
         }
 
+        update_idl_probe_interval(ovnsb_idl_loop.idl, vtep_idl_loop.idl);
+
         if (ovsdb_idl_has_ever_connected(ovnsb_idl_loop.idl) &&
             ovsdb_idl_has_ever_connected(vtep_idl_loop.idl) &&
             check_northd_version(vtep_idl_loop.idl, ovnsb_idl_loop.idl,
@@ -284,10 +306,12 @@ parse_options(int argc, char *argv[])
 
         switch (c) {
         case 'd':
+            free(ovnsb_remote);
             ovnsb_remote = xstrdup(optarg);
             break;
 
         case 'D':
+            free(vtep_remote);
             vtep_remote = xstrdup(optarg);
             break;
 
