@@ -16,10 +16,11 @@
 #ifndef STATCTRL_H
 #define STATCTRL_H
 
-#include "mac_cache.h"
+#include "mac-cache.h"
 
 void statctrl_init(void);
 void statctrl_run(struct ovsdb_idl_txn *ovnsb_idl_txn,
+                  struct ovsdb_idl_index *sbrec_port_binding_by_name,
                   struct mac_cache_data *mac_cache_data);
 void statctrl_update(const char *br_int_name);
 void statctrl_wait(struct ovsdb_idl_txn *ovnsb_idl_txn);
