@@ -137,7 +137,7 @@ az_run(struct ic_context *ctx)
      * "ovn-ic-sbctl destroy avail <az>". */
     static char *az_name;
     const struct icsbrec_availability_zone *az;
-    if (az_name && strcmp(az_name, nb_global->name)) {
+    if (ctx->ovnisb_txn && az_name && strcmp(az_name, nb_global->name)) {
         ICSBREC_AVAILABILITY_ZONE_FOR_EACH (az, ctx->ovnisb_idl) {
             /* AZ name update locally need to update az in ISB. */
             if (nb_global->name[0] && !strcmp(az->name, az_name)) {
@@ -1068,13 +1068,10 @@ prefix_is_black_listed(const struct smap *nb_options,
                 continue;
             }
         } else {
-            struct in6_addr mask = ipv6_create_mask(plen);
-            /* First calculate the difference between bl_prefix and prefix, so
-             * use the bl mask to ensure prefixes are correctly validated.
-             * e.g.: 2005:1734:5678::/50 is a subnet of 2005:1234::/21 */
-            struct in6_addr m_prefixes = ipv6_addr_bitand(prefix, &bl_prefix);
-            struct in6_addr m_prefix = ipv6_addr_bitand(&m_prefixes, &mask);
-            struct in6_addr m_bl_prefix = ipv6_addr_bitand(&bl_prefix, &mask);
+            struct in6_addr bl_mask = ipv6_create_mask(bl_plen);
+            struct in6_addr m_prefix = ipv6_addr_bitand(prefix, &bl_mask);
+            struct in6_addr m_bl_prefix = ipv6_addr_bitand(&bl_prefix,
+                                                           &bl_mask);
             if (!ipv6_addr_equals(&m_prefix, &m_bl_prefix)) {
                 continue;
             }
@@ -1123,6 +1120,8 @@ add_to_routes_ad(struct hmap *routes_ad, const struct in6_addr prefix,
                  const struct nbrec_logical_router_static_route *nb_route,
                  const struct nbrec_logical_router *nb_lr)
 {
+    ovs_assert(nb_route || nb_lrp);
+
     if (route_table == NULL) {
         route_table = "";
     }
@@ -1143,9 +1142,15 @@ add_to_routes_ad(struct hmap *routes_ad, const struct in6_addr prefix,
         hmap_insert(routes_ad, &ic_route->node, hash);
     } else {
         static struct vlog_rate_limit rl = VLOG_RATE_LIMIT_INIT(5, 1);
-        VLOG_WARN_RL(&rl, "Duplicate route advertisement was suppressed! NB "
-                     "route uuid: "UUID_FMT,
-                     UUID_ARGS(&nb_route->header_.uuid));
+        const char *msg_fmt = "Duplicate %s route advertisement was "
+                              "suppressed! NB %s uuid: "UUID_FMT;
+        if (nb_route) {
+            VLOG_WARN_RL(&rl, msg_fmt, origin, "route",
+                         UUID_ARGS(&nb_route->header_.uuid));
+        } else {
+            VLOG_WARN_RL(&rl, msg_fmt, origin, "lrp",
+                         UUID_ARGS(&nb_lrp->header_.uuid));
+        }
     }
 }
 
@@ -1262,11 +1267,52 @@ route_has_local_gw(const struct nbrec_logical_router *lr,
     return false;
 }
 
+static bool
+lrp_has_neighbor_in_ts(const struct nbrec_logical_router_port *lrp,
+                       struct in6_addr *nexthop)
+{
+    if (!lrp || !nexthop) {
+        return false;
+    }
+
+    struct lport_addresses lrp_networks;
+    if (!extract_lrp_networks(lrp, &lrp_networks)) {
+        destroy_lport_addresses(&lrp_networks);
+        return false;
+    }
+
+    if (IN6_IS_ADDR_V4MAPPED(nexthop)) {
+        ovs_be32 neigh_prefix_v4 = in6_addr_get_mapped_ipv4(nexthop);
+        for (size_t i = 0; i < lrp_networks.n_ipv4_addrs; i++) {
+            struct ipv4_netaddr address = lrp_networks.ipv4_addrs[i];
+            if (address.network == (neigh_prefix_v4 & address.mask)) {
+                destroy_lport_addresses(&lrp_networks);
+                return true;
+            }
+        }
+    } else {
+        for (size_t i = 0; i < lrp_networks.n_ipv6_addrs; i++) {
+            struct ipv6_netaddr address = lrp_networks.ipv6_addrs[i];
+            struct in6_addr neigh_prefix = ipv6_addr_bitand(nexthop,
+                                                            &address.mask);
+            if (ipv6_addr_equals(&address.network, &neigh_prefix)) {
+                destroy_lport_addresses(&lrp_networks);
+                return true;
+            }
+        }
+    }
+
+    destroy_lport_addresses(&lrp_networks);
+    return false;
+}
+
 static bool
 route_need_learn(const struct nbrec_logical_router *lr,
                  const struct icsbrec_route *isb_route,
                  struct in6_addr *prefix, unsigned int plen,
-                 const struct smap *nb_options)
+                 const struct smap *nb_options,
+                 const struct nbrec_logical_router_port *ts_lrp,
+                 struct in6_addr *nexthop)
 {
     if (!smap_get_bool(nb_options, "ic-route-learn", false)) {
         return false;
@@ -1291,6 +1337,10 @@ route_need_learn(const struct nbrec_logical_router *lr,
         return false;
     }
 
+    if (!lrp_has_neighbor_in_ts(ts_lrp, nexthop)) {
+        return false;
+    }
+
     return true;
 }
 
@@ -1312,6 +1362,20 @@ get_lrp_name_by_ts_port_name(struct ic_context *ctx, const char *ts_port_name)
     return smap_get(&nb_lsp->options, "router-port");
 }
 
+static const struct nbrec_logical_router_port *
+get_lrp_by_lrp_name(struct ic_context *ctx, const char *lrp_name)
+{
+    const struct nbrec_logical_router_port *lrp;
+    const struct nbrec_logical_router_port *lrp_key =
+        nbrec_logical_router_port_index_init_row(ctx->nbrec_lrp_by_name);
+    nbrec_logical_router_port_index_set_name(lrp_key, lrp_name);
+    lrp = nbrec_logical_router_port_index_find(ctx->nbrec_lrp_by_name,
+                                               lrp_key);
+    nbrec_logical_router_port_index_destroy_row(lrp_key);
+
+    return lrp;
+}
+
 static const char *
 get_route_table_by_lrp_name(struct ic_context *ctx, const char *lrp_name)
 {
@@ -1329,6 +1393,67 @@ get_route_table_by_lrp_name(struct ic_context *ctx, const char *lrp_name)
     return "";  /* <main> route table */
 }
 
+static const struct nbrec_logical_router_port *
+find_lrp_of_nexthop(struct ic_context *ctx,
+                    const struct icsbrec_route *isb_route)
+{
+    const struct nbrec_logical_router_port *lrp;
+    const struct nbrec_logical_switch *ls;
+    ls = find_ts_in_nb(ctx, isb_route->transit_switch);
+    if (!ls) {
+        return NULL;
+    }
+
+    struct in6_addr nexthop;
+    if (!ip46_parse(isb_route->nexthop, &nexthop)) {
+        return NULL;
+    }
+
+    for (size_t i = 0; i < ls->n_ports; i++) {
+        char *lsp_name = ls->ports[i]->name;
+        const char *lrp_name = get_lrp_name_by_ts_port_name(ctx,
+                                                            lsp_name);
+        if (!lrp_name) {
+            continue;
+        }
+
+        lrp = get_lrp_by_lrp_name(ctx, lrp_name);
+        if (!lrp) {
+            continue;
+        }
+
+        struct lport_addresses lrp_networks;
+        if (!extract_lrp_networks(lrp, &lrp_networks)) {
+            destroy_lport_addresses(&lrp_networks);
+            continue;
+        }
+
+        if (IN6_IS_ADDR_V4MAPPED(&nexthop)) {
+            ovs_be32 nexthop_v4 = in6_addr_get_mapped_ipv4(&nexthop);
+            for (size_t i_v4 = 0; i_v4  < lrp_networks.n_ipv4_addrs; i_v4++) {
+                struct ipv4_netaddr address = lrp_networks.ipv4_addrs[i_v4];
+                if (address.addr == nexthop_v4) {
+                    destroy_lport_addresses(&lrp_networks);
+                    return lrp;
+                }
+            }
+        } else {
+            for (size_t i_v6 = 0; i_v6 < lrp_networks.n_ipv6_addrs; i_v6++) {
+                struct ipv6_netaddr address = lrp_networks.ipv6_addrs[i_v6];
+                struct in6_addr nexthop_v6 = ipv6_addr_bitand(&nexthop,
+                                                              &address.mask);
+                if (ipv6_addr_equals(&address.network, &nexthop_v6)) {
+                    destroy_lport_addresses(&lrp_networks);
+                    return lrp;
+                }
+            }
+        }
+        destroy_lport_addresses(&lrp_networks);
+    }
+
+    return NULL;
+}
+
 static bool
 lrp_is_ts_port(struct ic_context *ctx, struct ic_router_info *ic_lr,
                const char *lrp_name)
@@ -1358,9 +1483,11 @@ sync_learned_routes(struct ic_context *ctx,
 
     const char *lrp_name, *ts_route_table;
     const struct icsbrec_port_binding *isb_pb;
+    const struct nbrec_logical_router_port *lrp;
     for (int i = 0; i < ic_lr->n_isb_pbs; i++) {
         isb_pb = ic_lr->isb_pbs[i];
         lrp_name = get_lrp_name_by_ts_port_name(ctx, isb_pb->logical_port);
+        lrp = get_lrp_by_lrp_name(ctx, lrp_name);
         ts_route_table = get_route_table_by_lrp_name(ctx, lrp_name);
 
         isb_route_key = icsbrec_route_index_init_row(ctx->icsbrec_route_by_ts);
@@ -1403,7 +1530,7 @@ sync_learned_routes(struct ic_context *ctx,
                 continue;
             }
             if (!route_need_learn(ic_lr->lr, isb_route, &prefix, plen,
-                                  &nb_global->options)) {
+                                  &nb_global->options, lrp, &nexthop)) {
                 continue;
             }
 
@@ -1694,7 +1821,7 @@ delete_orphan_ic_routes(struct ic_context *ctx,
             ctx->icnbrec_transit_switch_by_name, t_sw_key);
         icnbrec_transit_switch_index_destroy_row(t_sw_key);
 
-        if (!t_sw) {
+        if (!t_sw || !find_lrp_of_nexthop(ctx, isb_route)) {
             static struct vlog_rate_limit rl = VLOG_RATE_LIMIT_INIT(5, 1);
             VLOG_INFO_RL(&rl, "Deleting orphan ICDB:Route: %s->%s (%s, rtb:%s,"
                          " transit switch: %s)", isb_route->ip_prefix,
@@ -2117,6 +2244,8 @@ main(int argc, char *argv[])
                          &nbrec_logical_router_col_external_ids);
 
     ovsdb_idl_add_table(ovnnb_idl_loop.idl, &nbrec_table_logical_router_port);
+    ovsdb_idl_add_column(ovnnb_idl_loop.idl,
+                         &nbrec_logical_router_port_col_mac);
     ovsdb_idl_add_column(ovnnb_idl_loop.idl,
                          &nbrec_logical_router_port_col_name);
     ovsdb_idl_add_column(ovnnb_idl_loop.idl,
@@ -2409,7 +2538,7 @@ ovn_ic_resume(struct unixctl_conn *conn, int argc OVS_UNUSED,
 {
     struct ic_state *state = state_;
     state->paused = false;
-
+    poll_immediate_wake();
     unixctl_command_reply(conn, NULL);
 }
 
