@@ -32,6 +32,7 @@
 #include "stream.h"
 #include "svec.h"
 #include "unixctl.h"
+#include "dummy.h"
 
 VLOG_DEFINE_THIS_MODULE(ovn_util);
 
@@ -815,6 +816,23 @@ str_tolower(const char *orig)
     return copy;
 }
 
+/* This is a wrapper function which get the value associated with 'key' in
+ * 'smap' and converts it to a long long. If 'key' is not in 'smap' or a
+ * valid unsigned integer can't be parsed from its value, returns 'def'.
+ */
+long long
+ovn_smap_get_llong(const struct smap *smap, const char *key, long long def)
+{
+    const char *value = smap_get(smap, key);
+    long long ll_value;
+
+    if (!value || !str_to_llong(value, 10, &ll_value)) {
+        return def;
+    }
+
+    return ll_value;
+}
+
 /* For a 'key' of the form "IP:port" or just "IP", sets 'port',
  * 'ip_address' and 'ip' ('struct in6_addr' IPv6 or IPv4 mapped address).
  * The caller must free() the memory allocated for 'ip_address'.
@@ -847,8 +865,12 @@ ip_address_and_port_from_lb_key(const char *key, char **ip_address,
  * modified or a stage is added to a logical pipeline.
  *
  * This value is also used to handle some backward compatibility during
- * upgrading. It should never decrease or rewind. */
-#define OVN_INTERNAL_MINOR_VER 6
+ * upgrading. It should never decrease or rewind.
+ *
+ * NOTE: If OVN_NORTHD_PIPELINE_CSUM is updated make sure to double check
+ * whether an update of OVN_INTERNAL_MINOR_VER is required. */
+#define OVN_NORTHD_PIPELINE_CSUM "962040559 9628"
+#define OVN_INTERNAL_MINOR_VER 8
 
 /* Returns the OVN version. The caller must free the returned value. */
 char *
@@ -1288,3 +1310,18 @@ ovn_exit_args_finish(struct ovn_exit_args *exit_args)
     }
     free(exit_args->conns);
 }
+
+static void
+ovn_enable_timewarp(struct unixctl_conn *conn, int argc OVS_UNUSED,
+                    const char *argv[] OVS_UNUSED, void *arg OVS_UNUSED)
+{
+    timeval_dummy_register();
+    unixctl_command_reply(conn, NULL);
+}
+
+void
+ovn_debug_commands_register(void)
+{
+    unixctl_command_register("debug/enable-timewarp", "", 0, 0,
+                             ovn_enable_timewarp, NULL);
+}
