@@ -210,6 +210,9 @@ char *normalize_v46_prefix(const struct in6_addr *prefix, unsigned int plen);
  */
 char *str_tolower(const char *orig);
 
+long long ovn_smap_get_llong(const struct smap *smap, const char *key,
+                             long long def);
+
 /* OVN daemon options. Taken from ovs/lib/daemon.h. */
 #define OVN_DAEMON_OPTION_ENUMS                     \
     OVN_OPT_DETACH,                                 \
@@ -477,4 +480,5 @@ void ovn_exit_command_callback(struct unixctl_conn *conn, int argc,
                                const char *argv[], void *exit_args_);
 void ovn_exit_args_finish(struct ovn_exit_args *exit_args);
 
+void ovn_debug_commands_register(void);
 #endif /* OVN_UTIL_H */
